@@ -9,6 +9,7 @@ EXTENSIONS = {
     'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
+    'bzl': {'text', 'bazel'},
     'c': {'text', 'c'},
     'cc': {'text', 'c++'},
     'cfg': {'text'},
@@ -78,7 +79,8 @@ EXTENSIONS = {
     'jade': {'text', 'jade'},
     'jar': {'binary', 'zip', 'jar'},
     'java': {'text', 'java'},
-    'jenkinsfile': {'text', 'groovy'},
+    'jenkins': {'text', 'groovy', 'jenkins'},
+    'jenkinsfile': {'text', 'groovy', 'jenkins'},
     'jinja': {'text', 'jinja'},
     'jinja2': {'text', 'jinja'},
     'jpeg': {'binary', 'image', 'jpeg'},
@@ -261,8 +263,8 @@ NAMES = {
     '.zshrc': EXTENSIONS['zsh'],
     '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
-    'BUILD': {'text', 'bazel'},
-    'BUILD.bazel': {'text', 'bazel'},
+    'BUILD': EXTENSIONS['bzl'],
+    'BUILD.bazel': EXTENSIONS['bzl'],
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'CHANGELOG': EXTENSIONS['txt'],
     'CONTRIBUTING': EXTENSIONS['txt'],
@@ -271,7 +273,7 @@ NAMES = {
     'Gemfile': EXTENSIONS['rb'],
     'Gemfile.lock': {'text'},
     'GNUmakefile': EXTENSIONS['mk'],
-    'Jenkinsfile': {'text', 'groovy'},
+    'Jenkinsfile': EXTENSIONS['jenkins'],
     'LICENSE': EXTENSIONS['txt'],
     'MAINTAINERS': EXTENSIONS['txt'],
     'Makefile': EXTENSIONS['mk'],
@@ -286,4 +288,5 @@ NAMES = {
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
     'setup.cfg': EXTENSIONS['ini'],
+    'WORKSPACE': EXTENSIONS['bzl'],
 }
